@@ -63,7 +63,7 @@ function addRemoteTarball_ (u, tmp, shasum, auth, cb) {
       var sc = response && response.statusCode
       var statusRetry = !sc || (sc === 408 || sc >= 500)
       if (er && statusRetry && operation.retry(er)) {
-        log.info("retry", "will retry, error on last attempt: " + er)
+        log.warn("retry", "will retry, error on last attempt: " + er)
         return
       }
       cb(er, response, shasum)
